@@ -618,12 +618,9 @@ $lng['ticket']['subject'] = 'Sujet';
 $lng['ticket']['status'] = 'Etat';
 $lng['ticket']['lastreplier'] = 'Derni&egrave;re r&eacute;ponse de';
 $lng['ticket']['priority'] = 'Priorit&eacute;';
-$lng['ticket']['low'] = '<span class="ticket_low">Basse</span>';
-$lng['ticket']['normal'] = '<span class="ticket_normal">Normale</span>';
-$lng['ticket']['high'] = '<span class="ticket_high">Haute</span>';
-$lng['ticket']['unf_low'] = 'Basse';
-$lng['ticket']['unf_normal'] = 'Normale';
-$lng['ticket']['unf_high'] = 'Haute';
+$lng['ticket']['low'] = 'Basse';
+$lng['ticket']['normal'] = 'Normale';
+$lng['ticket']['high'] = 'Haute';
 $lng['ticket']['lastchange'] = 'Dernier changement';
 $lng['ticket']['lastchange_from'] = 'Depuis (jj.mm.aaaa)';
 $lng['ticket']['lastchange_to'] = 'Jusqu\'au (jj.mm.aaaa)';
